varying mediump vec2 vTex;
uniform lowp sampler2D samplerFront;
uniform mediump vec2 pixelSize;
uniform mediump vec2 srcStart;
uniform mediump vec2 srcEnd;
uniform mediump vec2 destStart;
uniform mediump vec2 destEnd;
uniform mediump float seconds;
uniform mediump float samples;
uniform mediump float exposure;
uniform mediump float bokehSize;
precision mediump float;

//based on a shader by XorDev

mat2 ang = mat2(-0.7373688, -0.6754904, 0.6754904,  -0.7373688);
	
void main(void)
{
	//Initialize blur output color
	vec4 blur = vec4(0);
	
	//Total weight from all samples
	float total = 0.;
	
	//First sample offset
	float scale = bokehSize * inversesqrt(samples);

	vec2 srcSize = srcEnd - srcStart;

	vec2 point = vec2(scale,0);

	//Look through all the samples
	for(float i = 0.; i < 512.0; i++)
	{
		//Rotate point direction
		point *= ang;
		//Get sample coordinates
		vec2 uv = vTex + point * sqrt(i) * pixelSize;
		mediump vec2 n = (uv - srcStart) / srcSize;

		n = clamp(n, 0.0, 1.0);
       	lowp vec4 samp = texture2D(samplerFront, n * srcSize + srcStart);

		//unpremultiply alpha
		if (samp.a != 0.0)
			samp.rgb /= samp.a;

		samp.rgb = exp(samp.rgb * exposure);

		//Add sample to total and remultiply alpha
		blur += vec4(samp.rgb * samp.a, samp.a);

		if(i  >= samples){
        break;
        }
	}
	//Get sample average
	blur /= samples;

	//unpremultiply alpha
	if (blur.a != 0.0)
			blur.rgb /= blur.a;

	//set out an remultiply alpha
	gl_FragColor =  vec4((log(blur.rgb) / exposure) * blur.a, blur.a);
}